# Vulnerability Disclosure

The Illumio team and community take security bugs in all Illumio projects seriously. If you believe you have found a potential security vulnerability in the `illumio` package, please reach out directly to [Duncan Sommerville](mailto:duncan.sommerville@illumio.com) and the [Illumio App Integrations Team](mailto:app-integrations@illumio.com). **Please do not file a public issue.**

Please include code you used to find the problem and the shortest amount of code necessary to reproduce it.

Please do not disclose the issue to anyone else. We will respect your privacy and will only publicize your involvement if you grant us permission. We appreciate your efforts to responsibly disclose your findings, and will make every effort to acknowledge your contributions if desired.
